colour.phenomenons Package — Colour 0.3.0 documentation

# colour.phenomenons Package

## Sub-Modules

- colour.phenomenons.rayleigh Module
  - Rayleigh Optical Depth - Scattering in the Atmosphere

## Module Contents

`colour.phenomenons.` `scattering_cross_section`(wavelength, CO2_concentration=300, temperature=288.15, avogadro_constant=6.02214179e+23, n_s=<function air_refraction_index_bodhaine1999 at 0x102e5e500>, F_air=<function F_air_bodhaine1999 at 0x102e5e7d0>)

  Returns the scattering cross section per molecule \(\sigma\) of dry air as function of wavelength \(\lambda\) in centimeters (cm) using given \(CO_2\) concentration in parts per million (ppm) and temperature \(T[K]\) in kelvin degrees following Van de Hulst (1957) method.

  Parameters: | wavelength (numeric) – Wavelength \(\lambda\) in centimeters (cm). CO2_concentration (numeric, optional) – \(CO_2\) concentration in parts per million (ppm). temperature (numeric, optional) – Air temperature \(T[K]\) in kelvin degrees. avogadro_constant (numeric, optional) – Avogadro‘s number (molecules \(mol^{-1}\)). n_s (object) – Air refraction index \(n_s\) computation method. F_air (object) – \((6+3_p)/(6-7_p)\), the depolarisation term \(F(air)\) or King Factor computation method.
  Returns: | Scattering cross section per molecule \(\sigma\) of dry air.
  Return type: | numeric

  Warning

  Unlike most objects of `colour.phenomenons.rayleigh` module, `colour.phenomenons.rayleigh.scattering_cross_section()` expects wavelength \(\lambda\) to be expressed in centimeters (cm).

  Examples

      >>> scattering_cross_section(555 * 10e-8)
      4.6613309...e-27

`colour.phenomenons.` `rayleigh_optical_depth`(wavelength, CO2_concentration=300, temperature=288.15, pressure=101325, latitude=0, altitude=0, avogadro_constant=6.02214179e+23, n_s=<function air_refraction_index_bodhaine1999 at 0x102e5e500>, F_air=<function F_air_bodhaine1999 at 0x102e5e7d0>)

  Returns the rayleigh optical depth \(T_r(\lambda)\) as function of wavelength \(\lambda\) in centimeters (cm).

  Parameters: | wavelength (numeric) – Wavelength \(\lambda\) in centimeters (cm). CO2_concentration (numeric, optional) – \(CO_2\) concentration in parts per million (ppm). temperature (numeric, optional) – Air temperature \(T[K]\) in kelvin degrees. pressure (numeric) – Surface pressure \(P\) of the measurement site. latitude (numeric, optional) – Latitude of the site in degrees. altitude (numeric, optional) – Altitude of the site in meters. avogadro_constant (numeric, optional) – Avogadro‘s number (molecules \(mol^{-1}\)). n_s (object) – Air refraction index \(n_s\) computation method. F_air (object) – \((6+3_p)/(6-7_p)\), the depolarisation term \(F(air)\) or King Factor computation method.
  Returns: | Rayleigh optical depth \(T_r(\lambda)\).
  Return type: | numeric

  Warning

  Unlike most objects of `colour.phenomenons.rayleigh` module, `colour.phenomenons.rayleigh.rayleigh_optical_depth()` expects wavelength \(\lambda\) to be expressed in centimeters (cm).

  Examples

      >>> rayleigh_optical_depth(555 * 10e-8)
      0.1004070...

`colour.phenomenons.` `rayleigh_scattering`(wavelength, CO2_concentration=300, temperature=288.15, pressure=101325, latitude=0, altitude=0, avogadro_constant=6.02214179e+23, n_s=<function air_refraction_index_bodhaine1999 at 0x102e5e500>, F_air=<function F_air_bodhaine1999 at 0x102e5e7d0>)

  Returns the rayleigh optical depth \(T_r(\lambda)\) as function of wavelength \(\lambda\) in centimeters (cm).

  Parameters: | wavelength (numeric) – Wavelength \(\lambda\) in centimeters (cm). CO2_concentration (numeric, optional) – \(CO_2\) concentration in parts per million (ppm). temperature (numeric, optional) – Air temperature \(T[K]\) in kelvin degrees. pressure (numeric) – Surface pressure \(P\) of the measurement site. latitude (numeric, optional) – Latitude of the site in degrees. altitude (numeric, optional) – Altitude of the site in meters. avogadro_constant (numeric, optional) – Avogadro‘s number (molecules \(mol^{-1}\)). n_s (object) – Air refraction index \(n_s\) computation method. F_air (object) – \((6+3_p)/(6-7_p)\), the depolarisation term \(F(air)\) or King Factor computation method.
  Returns: | Rayleigh optical depth \(T_r(\lambda)\).
  Return type: | numeric

  Warning

  Unlike most objects of `colour.phenomenons.rayleigh` module, `colour.phenomenons.rayleigh.rayleigh_optical_depth()` expects wavelength \(\lambda\) to be expressed in centimeters (cm).

  Examples

      >>> rayleigh_optical_depth(555 * 10e-8)
      0.1004070...

`colour.phenomenons.` `rayleigh_scattering_spd`(shape=SpectralShape(360, 830, 1), CO2_concentration=300, temperature=288.15, pressure=101325, latitude=0, altitude=0, avogadro_constant=6.02214179e+23, n_s=<function air_refraction_index_bodhaine1999 at 0x102e5e500>, F_air=<function F_air_bodhaine1999 at 0x102e5e7d0>)

  Returns the rayleigh spectral power distribution for given spectral shape.

  Parameters: | shape (SpectralShape, optional) – Spectral shape used to create the rayleigh scattering spectral power distribution. CO2_concentration (numeric, optional) – \(CO_2\) concentration in parts per million (ppm). temperature (numeric, optional) – Air temperature \(T[K]\) in kelvin degrees. pressure (numeric) – Surface pressure \(P\) of the measurement site. latitude (numeric, optional) – Latitude of the site in degrees. altitude (numeric, optional) – Altitude of the site in meters. avogadro_constant (numeric, optional) – Avogadro‘s number (molecules \(mol^{-1}\)). n_s (object) – Air refraction index \(n_s\) computation method. F_air (object) – \((6+3_p)/(6-7_p)\), the depolarisation term \(F(air)\) or King Factor computation method.
  Returns: | Rayleigh optical depth spectral power distribution.
  Return type: | SpectralPowerDistribution

  Examples

      >>> rayleigh_scattering_spd()
      <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x...>